==> nextcloud-27.1.11.tgz: nextcloud/apps/suspicious_login/l10n/sr.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Примећена нова локација пријаве",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Притиском на дугме можете да добијете више информација. Отвориће се %s и приказаће се информације у вези са сумњивом IP адресом.",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Примећена је нова пријава на Ваш налог. IP адреса %s хе класификована као сумњива. Ако сте ово били ви, игноришите ову поруку. Иначе бисте требали да измените лозинку.",
    "More information ↗" : "Више информација ↗",
    "Suspicious Login" : "Сумњиве Пријаве",
    "New login detected" : "Примећена нова пријава",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Детектуј и обавештавај о сумњивим IP адресама које се пријављују на Некстклауд\n\t",
    "Suspicious login detection" : "Детекција сумњивих пријава",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Апликација сумњивих пријава је укључена на овој инстанци. Пратиће IP адресе са којих се људи пријављују и градиће класификатор који упозорава када пријављивање дође са сумњиве IP адресе.",
    "Training data statistics" : "Статистика тренинг података",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "До сада је апликација ухватила {total} пријава (укључујући и клијентске конекције) од чега има {distinct} различитих (IP, UID) парова.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Статистика модела за класификацију",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Модела класификатора још није истрениран. Ово обично значи да сте недавно укључили апликацију. Пошто тренирање модела захтева добре податке, апликација чека док не ухвате пријаве бар {days} дана.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "За време евалуације, последњи модел (истрениран {time}) је испало да хвата {recall}% сумњивих пријава (осетљивост), док је {precision}% пријава класификовано као сумњиво стварно било сумњиво (прецизност). Испод можете видети историјат перформанси модела.",
    "Precision" : "Прецизност",
    "Recall" : "Осетљивост"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-28.0.9.tgz: nextcloud/apps/suspicious_login/l10n/sr.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Примећена нова локација пријаве",
    "More info about the suspicious IP address available on %s" : "На %s се налази још информација у вези са сумњивом IP адресом",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Примећена је нова пријава на Ваш налог. IP адреса %s хе класификована као сумњива. Ако сте ово били ви, игноришите ову поруку. Иначе бисте требали да измените лозинку.",
    "Open %s ↗" : "Отвори %s ↗",
    "Suspicious Login" : "Сумњиве Пријаве",
    "New login detected" : "Примећена нова пријава",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Детектуј и обавештавај о сумњивим IP адресама које се пријављују на Некстклауд\n\t",
    "Suspicious login detection" : "Детекција сумњивих пријава",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Апликација сумњивих пријава је укључена на овој инстанци. Пратиће IP адресе са којих се људи пријављују и градиће класификатор који упозорава када пријављивање дође са сумњиве IP адресе.",
    "Training data statistics" : "Статистика тренинг података",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "До сада је апликација ухватила {total} пријава (укључујући и клијентске конекције) од чега има {distinct} различитих (IP, UID) парова.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Статистика модела за класификацију",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Модела класификатора још није истрениран. Ово обично значи да сте недавно укључили апликацију. Пошто тренирање модела захтева добре податке, апликација чека док не ухвате пријаве бар {days} дана.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "За време евалуације, последњи модел (истрениран {time}) је испало да хвата {recall}% сумњивих пријава (осетљивост), док је {precision}% пријава класификовано као сумњиво стварно било сумњиво (прецизност). Испод можете видети историјат перформанси модела.",
    "Precision" : "Прецизност",
    "Recall" : "Осетљивост",
    "More information ↗" : "Више информација ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Притиском на дугме можете да добијете више информација. Отвориће се %s и приказаће се информације у вези са сумњивом IP адресом."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
